@@ -25,14 +25,13 @@ from ..version import parse_version
 
 class Choco(PackageManager):
 
+    name = "Chocolatey"
+
     platforms = frozenset({WINDOWS})
 
     requirement = "0.10.4"
 
-    name = "Chocolatey"
-
-    global_args = ("--no-progress", "--no-color")
-    prepend_global_args = False
+    post_args = ("--no-progress", "--no-color")
 
     """
     .. code-block:: shell-session
@@ -59,20 +58,53 @@ class Choco(PackageManager):
 
         output = self.run_cli("list", "--local-only", "--limit-output")
 
-        if output:
-            regexp = re.compile(r"(.+)\|(.+)")
-            for package in output.splitlines():
-                match = regexp.match(package)
-                if match:
-                    package_id, installed_version = match.groups()
-                    installed[package_id] = {
-                        "id": package_id,
-                        "name": package_id,
-                        "installed_version": parse_version(installed_version),
-                    }
+        regexp = re.compile(r"(.+)\|(.+)")
+        for package in output.splitlines():
+            match = regexp.match(package)
+            if match:
+                package_id, installed_version = match.groups()
+                installed[package_id] = {
+                    "id": package_id,
+                    "name": package_id,
+                    "installed_version": parse_version(installed_version),
+                }
 
         return installed
 
+    @property
+    def outdated(self):
+        """Fetch outdated packages.
+
+        .. code-block:: shell-session
+
+            ► choco outdated --limit-output --no-progress --no-color
+            7zip.commandline|16.02.0.20170209|16.02.0.20170209|false
+            7zip.portable|18.1|18.1|false
+            atom|1.23.3|1.24.0|false
+            autohotkey.portable|1.1.28.00|1.1.28.00|false
+            bulkrenameutility|3.0.0.1|3.0.0.1|false
+            bulkrenameutility.install|3.0.0.1|3.0.0.1|false
+            calibre|3.17.0|3.17.0|false
+            chocolatey|0.10.8|0.10.8|false
+        """
+        outdated = {}
+
+        output = self.run_cli("outdated", "--limit-output")
+
+        regexp = re.compile(r"(.+)\|(.+)\|(.+)\|.+")
+        for package in output.splitlines():
+            match = regexp.match(package)
+            if match:
+                package_id, installed_version, latest_version = match.groups()
+                outdated[package_id] = {
+                    "id": package_id,
+                    "name": package_id,
+                    "latest_version": parse_version(latest_version),
+                    "installed_version": parse_version(installed_version),
+                }
+
+        return outdated
+
     def search(self, query, extended, exact):
         """Fetch matching packages.
 
@@ -104,7 +136,6 @@ class Choco(PackageManager):
 
             ► choco search virtualbox --exact --limit-output --no-progress --no-color
             virtualbox|6.1.0
-
         """
         matches = {}
 
@@ -118,15 +149,13 @@ class Choco(PackageManager):
 
         output = self.run_cli("search", query, query_params)
 
-        if output:
-            regexp = re.compile(r"(.+)\|(.+)")
-
-            for package_id, latest_version in regexp.findall(output):
-                matches[package_id] = {
-                    "id": package_id,
-                    "name": package_id,
-                    "latest_version": parse_version(latest_version),
-                }
+        regexp = re.compile(r"(.+)\|(.+)")
+        for package_id, latest_version in regexp.findall(output):
+            matches[package_id] = {
+                "id": package_id,
+                "name": package_id,
+                "latest_version": parse_version(latest_version),
+            }
 
         return matches
 
@@ -140,44 +169,8 @@ class Choco(PackageManager):
         super().install(package_id)
         return self.run_cli("install", package_id, "--yes", "--limit-output")
 
-    @property
-    def outdated(self):
-        """Fetch outdated packages.
-
-        .. code-block:: shell-session
-
-            ► choco outdated --limit-output --no-progress --no-color
-            7zip.commandline|16.02.0.20170209|16.02.0.20170209|false
-            7zip.portable|18.1|18.1|false
-            atom|1.23.3|1.24.0|false
-            autohotkey.portable|1.1.28.00|1.1.28.00|false
-            bulkrenameutility|3.0.0.1|3.0.0.1|false
-            bulkrenameutility.install|3.0.0.1|3.0.0.1|false
-            calibre|3.17.0|3.17.0|false
-            chocolatey|0.10.8|0.10.8|false
-        """
-        outdated = {}
-
-        output = self.run_cli("outdated", "--limit-output")
-
-        if output:
-            regexp = re.compile(r"(.+)\|(.+)\|(.+)\|.+")
-            for package in output.splitlines():
-                match = regexp.match(package)
-                if match:
-                    package_id, installed_version, latest_version = match.groups()
-                    outdated[package_id] = {
-                        "id": package_id,
-                        "name": package_id,
-                        "latest_version": parse_version(latest_version),
-                        "installed_version": parse_version(installed_version),
-                    }
-
-        return outdated
-
     def upgrade_cli(self, package_id="all"):
-        """
-        .. code-block:: shell-session
+        """.. code-block:: shell-session.
 
             ► choco upgrade ccleaner --yes --limit-output --no-progress --no-color
 
@@ -185,11 +178,9 @@ class Choco(PackageManager):
 
             ► choco upgrade all --yes --limit-output --no-progress --no-color
         """
-        return [
-            self.cli_path,
+        return self.build_cli(
             "upgrade",
             package_id,
             "--yes",
             "--limit-output",
-            self.global_args,
-        ]
+        )
