@@ -17,9 +17,9 @@
 
 import re
 
-from click_extra.logging import logger
 from click_extra.platform import LINUX
 
+from .. import logger
 from ..base import PackageManager
 from ..version import parse_version
 
@@ -64,21 +64,77 @@ class Flatpak(PackageManager):
             "--ostree-verbose",
         )
 
-        if output:
-            regexp = re.compile(
-                r"(?P<name>.+?)\t(?P<package_id>\S+)\t?(?P<latest_version>.*)"
-            )
-            for package in output.splitlines():
-                match = regexp.match(package)
-                if match:
-                    name, package_id, installed_version = match.groups()
-                    installed[package_id] = {
-                        "id": package_id,
-                        "name": name,
-                        "installed_version": parse_version(installed_version),
-                    }
+        regexp = re.compile(
+            r"(?P<name>.+?)\t(?P<package_id>\S+)\t?(?P<latest_version>.*)"
+        )
+
+        for package in output.splitlines():
+            match = regexp.match(package)
+            if match:
+                name, package_id, installed_version = match.groups()
+                installed[package_id] = {
+                    "id": package_id,
+                    "name": name,
+                    "installed_version": parse_version(installed_version),
+                }
+
         return installed
 
+    @property
+    def outdated(self):
+        """Fetch outdated packages from ``flatpak remote-ls`` output.
+
+        Raw CLI output samples:
+
+        .. code-block:: shell-session
+
+            ► flatpak remote-ls --app --updates --columns=name,application,version --ostree-verbose
+            GNOME Dictionary    org.gnome.Dictionary    3.26.0  stable  x86_64
+        """
+        outdated = {}
+
+        output = self.run_cli(
+            "remote-ls",
+            "--app",
+            "--updates",
+            "--columns=name,application,version",
+            "--ostree-verbose",
+        )
+
+        regexp = re.compile(
+            r"(?P<name>.+?)\t(?P<package_id>\S+)\t?(?P<latest_version>.*)"
+        )
+
+        for package in output.splitlines():
+            match = regexp.match(package)
+            if match:
+                name, package_id, latest_version = match.groups()
+
+                info_installed_output = self.run_cli(
+                    "info",
+                    "--ostree-verbose",
+                    package_id,
+                )
+
+                current_version = re.search(
+                    r"version:\s(?P<version>\S.*?)\n",
+                    info_installed_output,
+                    re.IGNORECASE,
+                )
+
+                installed_version = (
+                    current_version.group("version") if current_version else "unknow"
+                )
+
+                outdated[package_id] = {
+                    "id": package_id,
+                    "name": name,
+                    "latest_version": parse_version(latest_version),
+                    "installed_version": parse_version(installed_version),
+                }
+
+        return outdated
+
     def search(self, query, extended, exact):
         """Fetch matching packages from ``flatpak search`` output.
 
@@ -98,38 +154,36 @@ class Flatpak(PackageManager):
 
         output = self.run_cli("search", query, "--ostree-verbose")
 
-        if output:
-            regexp = re.compile(
-                r"""
-                ^(?P<package_name>\S+)\t
-                (?P<description>\S+)\t
-                (?P<package_id>\S+)\t
-                (?P<version>\S+)\t
-                (?P<branch>\S+)\t
-                (?P<remotes>.+)
-                """,
-                re.VERBOSE,
-            )
+        regexp = re.compile(
+            r"""
+            ^(?P<package_name>\S+)\t
+            (?P<description>\S+)\t
+            (?P<package_id>\S+)\t
+            (?P<version>\S+)\t
+            (?P<branch>\S+)\t
+            (?P<remotes>.+)
+            """,
+            re.VERBOSE,
+        )
 
-            for (
-                package_name,
-                description,
-                package_id,
-                version,
-                branch,
-                remotes,
-            ) in regexp.findall(output):
+        for (
+            package_name,
+            description,
+            package_id,
+            version,
+            branch,
+            remotes,
+        ) in regexp.findall(output):
 
-                # Filters out fuzzy matches, only keep stricly matching
-                # packages.
-                if exact and query not in (package_id, package_name):
-                    continue
+            # Filters out fuzzy matches, only keep stricly matching packages.
+            if exact and query not in (package_id, package_name):
+                continue
 
-                matches[package_id] = {
-                    "id": package_id,
-                    "name": package_name,
-                    "latest_version": parse_version(version),
-                }
+            matches[package_id] = {
+                "id": package_id,
+                "name": package_name,
+                "latest_version": parse_version(version),
+            }
 
         return matches
 
@@ -139,72 +193,16 @@ class Flatpak(PackageManager):
         .. code-block:: shell-session
 
             ► flatpak install org.gnome.Dictionary
-
         """
         super().install(package_id)
         return self.run_cli("install", package_id)
 
-    @property
-    def outdated(self):
-        """Fetch outdated packages from ``flatpak remote-ls`` output.
-
-        Raw CLI output samples:
-
-        .. code-block:: shell-session
-
-            ► flatpak remote-ls --app --updates --ostree-verbose
-            GNOME Dictionary    org.gnome.Dictionary    3.26.0  stable  x86_64
-        """
-        outdated = {}
-
-        output = self.run_cli(
-            "remote-ls",
-            "--app",
-            "--updates",
-            "--columns=name,application,version",
-            "--ostree-verbose",
-        )
-
-        if output:
-            regexp = re.compile(
-                r"(?P<name>.+?)\t(?P<package_id>\S+)\t?(?P<latest_version>.*)"
-            )
-            for package in output.splitlines():
-                match = regexp.match(package)
-                if match:
-                    name, package_id, latest_version = match.groups()
-
-                    info_installed_output = self.run_cli(
-                        "info",
-                        "--ostree-verbose",
-                        package_id,
-                    )
-                    current_version = re.search(
-                        r"version:\s(?P<version>\S.*?)\n",
-                        info_installed_output,
-                        re.IGNORECASE,
-                    )
-
-                    installed_version = (
-                        current_version.group("version")
-                        if current_version
-                        else "unknow"
-                    )
-
-                    outdated[package_id] = {
-                        "id": package_id,
-                        "name": name,
-                        "latest_version": parse_version(latest_version),
-                        "installed_version": parse_version(installed_version),
-                    }
-
-        return outdated
-
     def upgrade_cli(self, package_id=None):
-        cmd = [self.cli_path, self.global_args, "update", "--noninteractive"]
-        if package_id:
-            cmd.append(package_id)
-        return cmd
+        """.. code-block:: shell-session.
+
+        ► flatpak update --noninteractive org.gnome.Dictionary
+        """
+        return self.build_cli("update", "--noninteractive", package_id)
 
     def cleanup(self):
         """Runs:
