@@ -15,12 +15,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+import json
 import re
 
-import simplejson as json
-from click_extra.logging import logger
 from click_extra.platform import LINUX, MACOS
 
+from .. import logger
 from ..base import PackageManager
 from ..version import parse_version
 
@@ -29,8 +29,7 @@ class Homebrew(PackageManager):
 
     """Virtual package manager shared by brew and cask CLI defined below.
 
-    Homebrew is the umbrella project providing both brew and brew cask
-    commands.
+    Homebrew is the umbrella project providing both brew and brew cask commands.
     """
 
     platforms = frozenset({LINUX, MACOS})
@@ -42,6 +41,19 @@ class Homebrew(PackageManager):
     # Declare this manager as virtual, i.e. not tied to a real CLI.
     cli_names = None
 
+    extra_env = {
+        # Disable analytics.
+        "HOMEBREW_NO_ANALYTICS": "1",
+        # Disable configuration hints to reduce verbosity.
+        "HOMEBREW_NO_ENV_HINTS": "1",
+        # Do not let brew mix the update operation with others. Mpm has a separate "sync" command for that.
+        # This silo-ed behavior has been requested by user since the beginning of
+        # mpm: https://github.com/kdeldycke/meta-package-manager/issues/36
+        "HOMEBREW_NO_AUTO_UPDATE": "1",
+        # See: https://docs.brew.sh/FAQ#why-cant-i-open-a-mac-app-from-an-unidentified-developer
+        # "HOMEBREW_CASK_OPTS": "--no-quarantine",
+    }
+
     version_regex = r"Homebrew\s+(?P<version>\S+)"
     """
     .. code-block:: shell-session
@@ -52,19 +64,6 @@ class Homebrew(PackageManager):
         Homebrew/homebrew-cask (git revision 5095b; last commit 2018-12-28)
     """
 
-    prepend_global_args = False
-
-    def sync(self):
-        """Fetch content of remote taps.
-
-        .. code-block:: shell-session
-
-            ► brew update --quiet
-            Already up-to-date.
-        """
-        super().sync()
-        self.run_cli("update", "--quiet", skip_globals=True)
-
     @property
     def installed(self):
         """List installed packages from ``brew list`` output.
@@ -111,133 +110,20 @@ class Homebrew(PackageManager):
 
         output = self.run_cli("list", "--versions")
 
-        if output:
-            regexp = re.compile(r"(\S+)( \(!\))? (.+)")
-            for pkg_info in output.splitlines():
-                match = regexp.match(pkg_info)
-                if match:
-                    package_id, removed, versions = match.groups()
-                    installed[package_id] = {
-                        "id": package_id,
-                        "name": package_id,
-                        "installed_version":
-                        # Keep highest version found.
-                        max(map(parse_version, versions.split())),
-                    }
-
-        return installed
-
-    def search(self, query, extended, exact):
-        """Fetch matching packages from ``brew search`` output.
-
-        .. code-block:: shell-session
-
-            ► brew search sed
-            ==> Formulae
-            gnu-sed ✔                    libxdg-basedir               minised
-            ==> Casks
-            eclipse-dsl                       marsedit
-            focused                           physicseditor
-            google-adwords-editor             prefs-editor
-            licensed                          subclassed-mnemosyne
-
-        .. code-block:: shell-session
-
-            ► brew search sed --formulae
-            ==> Formulae
-            gnu-sed ✔                    libxdg-basedir               minised
-
-        .. code-block:: shell-session
-
-            ► brew search sed --cask
-            ==> Casks
-            eclipse-dsl                       marsedit
-            focused                           physicseditor
-            google-adwords-editor             prefs-editor
-            licensed                          subclassed-mnemosyne
-
-        .. code-block:: shell-session
-
-            ► brew search python --formulae
-            ==> Formulae
-            app-engine-python   boost-python3   python ✔          python-yq
-            boost-python        gst-python      python-markdown   python@3.8 ✔
-
-        .. code-block:: shell-session
-
-            ► brew search "/^ssed$/" --formulae
-            ==> Formulae
-            ssed
-
-        .. code-block:: shell-session
-
-            ► brew search "/^sed$/" --formulae
-            No formula or cask found for "/^sed$/".
-            Closed pull requests:
-            Merge ba7a794 (https://github.com/Homebrew/linuxbrew-core/pull/198)
-            R: disable Tcl (https://github.com/Homebrew/homebrew-core/pull/521)
-            (...)
-
-        More doc at: https://docs.brew.sh/Manpage#search-texttext
-        """
-        matches = {}
-
-        if extended:
-            logger.warning(
-                f"Extended search not supported for {self.id}. Fallback to Fuzzy."
-            )
-
-        # Use regexp for exact match.
-        if exact:
-            query = f"/^{query}$/"
-
-        output = self.run_cli("search", query)
-
-        if output:
-            regexp = re.compile(
-                r"""
-                (?:==>\s\S+\s)?           # Ignore section starting with '==>'.
-                (?P<package_id>[^\s✔]+)   # Anything not a whitespace or ✔.
-                """,
-                re.VERBOSE,
-            )
-
-            for package_id in regexp.findall(output):
-                matches[package_id] = {
+        regexp = re.compile(r"(\S+)( \(!\))? (.+)")
+        for pkg_info in output.splitlines():
+            match = regexp.match(pkg_info)
+            if match:
+                package_id, removed, versions = match.groups()
+                installed[package_id] = {
                     "id": package_id,
                     "name": package_id,
-                    "latest_version": None,
+                    "installed_version":
+                    # Keep highest version found.
+                    max(map(parse_version, versions.split())),
                 }
 
-        return matches
-
-    def install(self, package_id):
-        """Install one package.
-
-        .. code-block:: shell-session
-
-            ► brew install jpeginfo --formula
-            ==> Downloading https://ghcr.io/core/jpeginfo/manifests/1.6.1_1-1
-            ############################################################## 100.0%
-            ==> Downloading https://ghcr.io/core/jpeginfo/blobs/sha256:27bb35884368b83
-            ==> Downloading from https://pkg.githubcontent.com/ghcr1/blobs/sha256:27bb3
-            ############################################################## 100.0%
-            ==> Pouring jpeginfo--1.6.1_1.big_sur.bottle.1.tar.gz
-            🍺  /usr/local/Cellar/jpeginfo/1.6.1_1: 7 files, 77.6KB
-
-        .. code-block:: shell-session
-
-            ► brew install pngyu --cask
-            Updating Homebrew...
-            ==> Downloading https://nukesaq.github.io/Pngyu/download/Pngyu_mac_101.zip
-            ################################################################## 100.0%
-            ==> Installing Cask pngyu
-            ==> Moving App 'Pngyu.app' to '/Applications/Pngyu.app'
-            🍺  pngyu was successfully installed!
-
-        """
-        super().install(package_id)
-        return self.run_cli("install", package_id)
+        return installed
 
     @property
     def outdated(self):
@@ -356,6 +242,115 @@ class Homebrew(PackageManager):
 
         return outdated
 
+    def search(self, query, extended, exact):
+        """Fetch matching packages from ``brew search`` output.
+
+        .. code-block:: shell-session
+
+            ► brew search sed
+            ==> Formulae
+            gnu-sed ✔                    libxdg-basedir               minised
+            ==> Casks
+            eclipse-dsl                       marsedit
+            focused                           physicseditor
+            google-adwords-editor             prefs-editor
+            licensed                          subclassed-mnemosyne
+
+        .. code-block:: shell-session
+
+            ► brew search sed --formulae
+            ==> Formulae
+            gnu-sed ✔                    libxdg-basedir               minised
+
+        .. code-block:: shell-session
+
+            ► brew search sed --cask
+            ==> Casks
+            eclipse-dsl                       marsedit
+            focused                           physicseditor
+            google-adwords-editor             prefs-editor
+            licensed                          subclassed-mnemosyne
+
+        .. code-block:: shell-session
+
+            ► brew search python --formulae
+            ==> Formulae
+            app-engine-python   boost-python3   python ✔          python-yq
+            boost-python        gst-python      python-markdown   python@3.8 ✔
+
+        .. code-block:: shell-session
+
+            ► brew search "/^ssed$/" --formulae
+            ==> Formulae
+            ssed
+
+        .. code-block:: shell-session
+
+            ► brew search "/^sed$/" --formulae
+            No formula or cask found for "/^sed$/".
+            Closed pull requests:
+            Merge ba7a794 (https://github.com/Homebrew/linuxbrew-core/pull/198)
+            R: disable Tcl (https://github.com/Homebrew/homebrew-core/pull/521)
+            (...)
+
+        More doc at: https://docs.brew.sh/Manpage#search-texttext
+        """
+        matches = {}
+
+        if extended:
+            logger.warning(
+                f"Extended search not supported for {self.id}. Fallback to Fuzzy."
+            )
+
+        # Use regexp for exact match.
+        if exact:
+            query = f"/^{query}$/"
+
+        output = self.run_cli("search", query)
+
+        regexp = re.compile(
+            r"""
+            (?:==>\s\S+\s)?           # Ignore section starting with '==>'.
+            (?P<package_id>[^\s✔]+)   # Anything not a whitespace or ✔.
+            """,
+            re.VERBOSE,
+        )
+
+        for package_id in regexp.findall(output):
+            matches[package_id] = {
+                "id": package_id,
+                "name": package_id,
+                "latest_version": None,
+            }
+
+        return matches
+
+    def install(self, package_id):
+        """Install one package.
+
+        .. code-block:: shell-session
+
+            ► brew install jpeginfo --formula
+            ==> Downloading https://ghcr.io/core/jpeginfo/manifests/1.6.1_1-1
+            ############################################################## 100.0%
+            ==> Downloading https://ghcr.io/core/jpeginfo/blobs/sha256:27bb35884368b83
+            ==> Downloading from https://pkg.githubcontent.com/ghcr1/blobs/sha256:27bb3
+            ############################################################## 100.0%
+            ==> Pouring jpeginfo--1.6.1_1.big_sur.bottle.1.tar.gz
+            🍺  /usr/local/Cellar/jpeginfo/1.6.1_1: 7 files, 77.6KB
+
+        .. code-block:: shell-session
+
+            ► brew install pngyu --cask
+            ==> Downloading https://nukesaq.github.io/Pngyu/download/Pngyu_mac_101.zip
+            ################################################################## 100.0%
+            ==> Installing Cask pngyu
+            ==> Moving App 'Pngyu.app' to '/Applications/Pngyu.app'
+            🍺  pngyu was successfully installed!
+        """
+        super().install(package_id)
+        return self.run_cli("install", package_id)
+
     def upgrade_cli(self, package_id=None):
         """Returns the right CLI depending on weither formula or cask are
         concerned:
@@ -396,10 +391,6 @@ class Homebrew(PackageManager):
         .. code-block:: shell-session
 
             ► brew upgrade --cask
-            Updating Homebrew...
-            ==> Auto-updated Homebrew!
-            Updated Homebrew from 1654de327 to cfa03c8cc.
-            Updated 2 taps (homebrew/core and homebrew/cask).
             ==> Casks with `auto_updates` or `version :latest` will not be upgraded
             ==> Upgrading 1 outdated packages:
             aerial 2.0.7 -> 2.0.8
@@ -412,11 +403,37 @@ class Homebrew(PackageManager):
             ==> Moving Screen Saver to '/Users/kde/Library/Screen Savers/Aerial.saver'.
             ==> Purging files for version 2.0.7 of Cask aerial
             🍺  aerial was successfully upgraded!
+
+        .. code-block:: shell-session
+
+            ► brew upgrade dupeguru --cask
+            ==> Upgrading 1 outdated package:
+            dupeguru 4.2.0 -> 4.2.1
+            ==> Upgrading dupeguru
+            ==> Downloading https://github.com/arsenetar/dupeguru/releases/download/4.2.1/dupeguru_macOS_Qt_4.2.1.zi
+            ==> Downloading from https://objects.githubusercontent.com/github-production-release-asset-2e65be/108563
+            ######################################################################## 100.0%
+            ==> Backing App 'dupeguru.app' up to '/opt/homebrew/Caskroom/dupeguru/4.2.0/dupeguru.app'
+            ==> Removing App '/Applications/dupeguru.app'
+            ==> Moving App 'dupeguru.app' to '/Applications/dupeguru.app'
+            ==> Purging files for version 4.2.0 of Cask dupeguru
+            🍺  dupeguru was successfully upgraded!
         """
-        cmd = [self.cli_path, "upgrade", self.global_args]
-        if package_id:
-            cmd.append(package_id)
-        return cmd
+        return self.build_cli(
+            "upgrade",
+            package_id,
+        )
+
+    def sync(self):
+        """Fetch content of remote taps.
+
+        .. code-block:: shell-session
+
+            ► brew update --quiet
+            Already up-to-date.
+        """
+        super().sync()
+        self.run_cli("update", "--quiet", auto_post_args=False)
 
     def cleanup(self):
         """Scrub the cache, including latest version's downloads. Also remove unused
@@ -459,26 +476,28 @@ class Homebrew(PackageManager):
             Uninstalling /usr/local/Cellar/texi2html/5.0... (279 files, 6.2MB)
             Uninstalling /usr/local/Cellar/lua@5.1/5.1.5_8... (22 files, 245.6KB)
             Uninstalling /usr/local/Cellar/nasm/2.15.05... (29 files, 2.9MB)
-
         """
         super().cleanup()
-        self.run_cli("autoremove", skip_globals=True)
-        self.run_cli("cleanup", "-s", "--prune=all", skip_globals=True)
+        self.run_cli("autoremove", auto_post_args=False)
+        self.run_cli("cleanup", "-s", "--prune=all", auto_post_args=False)
 
 
 class Brew(Homebrew):
 
     name = "Homebrew Formulae"
+
     cli_names = ("brew",)
 
-    global_args = ("--formula",)
+    post_args = ("--formula",)
 
 
 class Cask(Homebrew):
 
+    name = "Homebrew Cask"
+
     # Casks are only available on macOS, not Linux.
     platforms = frozenset({MACOS})
-    name = "Homebrew Cask"
+
     cli_names = ("brew",)
 
-    global_args = ("--cask",)
+    post_args = ("--cask",)
