@@ -15,7 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-import simplejson as json
+import json
+
 from boltons.iterutils import remap
 from click_extra.platform import LINUX, MACOS, WINDOWS
 
@@ -25,12 +26,12 @@ from ..version import TokenizedString, parse_version
 
 class NPM(PackageManager):
 
+    name = "Node's npm"
+
     platforms = frozenset({LINUX, MACOS, WINDOWS})
 
     requirement = "4.0.0"
 
-    name = "Node's npm"
-
     """
     .. code-block:: shell-session
 
@@ -74,7 +75,7 @@ class NPM(PackageManager):
 
         .. code-block:: shell-session
 
-            ► npm list --global --json | jq
+            ► npm --global --json list | jq
             {
               "dependencies": {
                 "npm": {
@@ -129,6 +130,53 @@ class NPM(PackageManager):
 
         return installed
 
+    @property
+    def outdated(self):
+        """Fetch outdated packages from ``npm outdated`` output.
+
+        Raw CLI output samples:
+
+        .. code-block:: shell-session
+
+            ► npm --global --progress=false --json --no-update-notifier outdated
+            {
+              "my-linked-package": {
+                "current": "0.0.0-development",
+                "wanted": "linked",
+                "latest": "linked",
+                "location": "/Users/..."
+              },
+              "npm": {
+                "current": "3.10.3",
+                "wanted": "3.10.5",
+                "latest": "3.10.5",
+                "location": "/Users/..."
+              }
+            }
+        """
+        outdated = {}
+
+        output = self.run_cli(
+            "--global",
+            "--progress=false",
+            "--json",
+            "--no-update-notifier",
+            "outdated",
+        )
+
+        if output:
+            for package_id, values in json.loads(output).items():
+                if values["wanted"] == "linked":
+                    continue
+                outdated[package_id] = {
+                    "id": f"{package_id}@{values['latest']}",
+                    "name": package_id,
+                    "installed_version": parse_version(values["current"]),
+                    "latest_version": parse_version(values["latest"]),
+                }
+
+        return outdated
+
     def search(self, query, extended, exact):
         """Fetch matching packages from ``npm search`` output.
 
@@ -136,7 +184,7 @@ class NPM(PackageManager):
 
         .. code-block:: shell-session
 
-            ► npm search python --json | jq
+            ► npm search --json python | jq
             [
               {
                 "name": "python",
@@ -201,6 +249,10 @@ class NPM(PackageManager):
               },
               (...)
             ]
+
+        .. code-block:: shell-session
+
+            ► npm search --json --no-description python | jq
         """
         matches = {}
 
@@ -241,7 +293,6 @@ class NPM(PackageManager):
         .. code-block:: shell-session
 
             ► npm --global --progress=false --no-update-notifier install raven
-
         """
         super().install(package_id)
         return self.run_cli(
@@ -252,58 +303,21 @@ class NPM(PackageManager):
             package_id,
         )
 
-    @property
-    def outdated(self):
-        """Fetch outdated packages from ``npm outdated`` output.
+    def upgrade_cli(self, package_id=None, version=None):
+        """.. code-block:: shell-session.
 
-        Raw CLI output samples:
+            ► npm --global --progress=false --no-update-notifier install raven
 
         .. code-block:: shell-session
 
-            ► npm --global --progress=false --json outdated
-            {
-              "my-linked-package": {
-                "current": "0.0.0-development",
-                "wanted": "linked",
-                "latest": "linked",
-                "location": "/Users/..."
-              },
-              "npm": {
-                "current": "3.10.3",
-                "wanted": "3.10.5",
-                "latest": "3.10.5",
-                "location": "/Users/..."
-              }
-            }
+            ► npm --global --progress=false --no-update-notifier update
         """
-        outdated = {}
-
-        output = self.run_cli(
-            "--global",
-            "--progress=false",
-            "--json",
-            "--no-update-notifier",
-            "outdated",
-        )
-
-        if output:
-            for package_id, values in json.loads(output).items():
-                if values["wanted"] == "linked":
-                    continue
-                outdated[package_id] = {
-                    "id": f"{package_id}@{values['latest']}",
-                    "name": package_id,
-                    "installed_version": parse_version(values["current"]),
-                    "latest_version": parse_version(values["latest"]),
-                }
-
-        return outdated
-
-    def upgrade_cli(self, package_id=None, version=None):
-        cmd_args = ["--global", "--progress=false", "--no-update-notifier"]
+        cmd_args = ["update"]
         if package_id:
-            cmd_args.append("install")
-            cmd_args.append(f"{package_id}@{version}" if version else package_id)
-        else:
-            cmd_args.append("update")
-        return [self.cli_path] + cmd_args
+            cmd_args = [
+                "install",
+                f"{package_id}@{version}" if version else package_id,
+            ]
+        return self.build_cli(
+            "--global", "--progress=false", "--no-update-notifier", *cmd_args
+        )
