@@ -37,16 +37,6 @@ class OPKG(PackageManager):
         opkg version 0.3.6 (libsolv 0.7.5)
     """
 
-    def sync(self):
-        """
-
-        Raw CLI output samples:
-
-        .. code-block:: shell-session
-        """
-        super().sync()
-        self.run_cli("update")
-
     @property
     def installed(self):
         """Fetch installed packages from ``opkg list-installed`` output.
@@ -80,82 +70,18 @@ class OPKG(PackageManager):
 
         output = self.run_cli("list-installed")
 
-        if output:
-            regexp = re.compile(r"(\S+) - (\S+)")
-            for package in output.splitlines():
-                match = regexp.match(package)
-                if match:
-                    package_id, installed_version = match.groups()
-                    installed[package_id] = {
-                        "id": package_id,
-                        "name": package_id,
-                        "installed_version": parse_version(installed_version),
-                    }
-
-        return installed
-
-    def search(self, query, extended, exact):
-        """Simulate search by listing all packages."""
-        matches = {}
-
-        # opkg doesn't have a working 'search', so get all packages and
-        # filter the packages later.
-        output = self.run_cli("list")
-
-        if output:
-            regexp = re.compile(
-                r"""
-                (?P<package_id>\S+)
-                \ -\
-                (?P<version>\S+)
-                \ -\
-                (?P<description>.+)
-                """,
-                re.VERBOSE | re.MULTILINE,
-            )
-
-            for package_id, version, description in regexp.findall(output):
-
-                # Skip all non-stricly matching package IDs in exact mode.
-                if exact:
-                    if query != package_id:
-                        continue
-
-                else:
-                    # All other modes search for matching in package IDs and
-                    # names.
-                    searched_content = set(map(str, TokenizedString(package_id)))
-
-                    # Also search within the description in extended mode.
-                    if extended:
-                        searched_content.update(
-                            set(map(str, TokenizedString(description)))
-                        )
-
-                    # Skip package if not all sub-strings are present in the
-                    # searched content.
-                    query_parts = set(map(str, TokenizedString(query)))
-                    if not query_parts.issubset(searched_content):
-                        continue
-
-                matches[package_id] = {
+        regexp = re.compile(r"(\S+) - (\S+)")
+        for package in output.splitlines():
+            match = regexp.match(package)
+            if match:
+                package_id, installed_version = match.groups()
+                installed[package_id] = {
                     "id": package_id,
                     "name": package_id,
-                    "latest_version": parse_version(version),
+                    "installed_version": parse_version(installed_version),
                 }
 
-        return matches
-
-    def install(self, package_id):
-        """Install one package.
-
-        .. code-block:: shell-session
-
-            ► opkg install enigma2-hotplug
-
-        """
-        super().install(package_id)
-        return self.run_cli("install", package_id)
+        return installed
 
     @property
     def outdated(self):
@@ -173,23 +99,96 @@ class OPKG(PackageManager):
 
         output = self.run_cli("list-upgradable")
 
-        if output:
-            regexp = re.compile(r"(\S+) - (\S+) - (\S+)")
-            for package in output.splitlines():
-                match = regexp.match(package)
-                if match:
-                    package_id, installed_version, latest_version = match.groups()
-                    outdated[package_id] = {
-                        "id": package_id,
-                        "name": package_id,
-                        "latest_version": parse_version(latest_version),
-                        "installed_version": parse_version(installed_version),
-                    }
+        regexp = re.compile(r"(\S+) - (\S+) - (\S+)")
+        for package in output.splitlines():
+            match = regexp.match(package)
+            if match:
+                package_id, installed_version, latest_version = match.groups()
+                outdated[package_id] = {
+                    "id": package_id,
+                    "name": package_id,
+                    "latest_version": parse_version(latest_version),
+                    "installed_version": parse_version(installed_version),
+                }
 
         return outdated
 
+    def search(self, query, extended, exact):
+        """Simulate search by listing all packages.
+
+        .. code-block:: shell-session
+
+            ► opkg list
+        """
+        matches = {}
+
+        # opkg doesn't have a working 'search', so get all packages and
+        # filter the packages later.
+        output = self.run_cli("list")
+
+        regexp = re.compile(
+            r"""
+            (?P<package_id>\S+)
+            \ -\
+            (?P<version>\S+)
+            \ -\
+            (?P<description>.+)
+            """,
+            re.VERBOSE | re.MULTILINE,
+        )
+
+        for package_id, version, description in regexp.findall(output):
+            # Skip all non-stricly matching package IDs in exact mode.
+            if exact:
+                if query != package_id:
+                    continue
+            else:
+                # All other modes search for matching in package IDs and
+                # names.
+                searched_content = set(map(str, TokenizedString(package_id)))
+
+                # Also search within the description in extended mode.
+                if extended:
+                    searched_content.update(set(map(str, TokenizedString(description))))
+
+                # Skip package if not all sub-strings are present in the
+                # searched content.
+                query_parts = set(map(str, TokenizedString(query)))
+                if not query_parts.issubset(searched_content):
+                    continue
+
+            matches[package_id] = {
+                "id": package_id,
+                "name": package_id,
+                "latest_version": parse_version(version),
+            }
+
+        return matches
+
+    def install(self, package_id):
+        """Install one package.
+
+        .. code-block:: shell-session
+
+            ► opkg install enigma2-hotplug
+        """
+        super().install(package_id)
+        return self.run_cli("install", package_id)
+
     def upgrade_cli(self, package_id=None):
-        cmd = [self.cli_path, "upgrade"]
-        if package_id:
-            cmd.append(package_id)
-        return cmd
+        """.. code-block:: shell-session.
+
+        ► opkg upgrade enigma2-hotplug
+        """
+        return self.build_cli(
+            "upgrade",
+            package_id,
+        )
+
+    def sync(self):
+        """.. code-block:: shell-session.
+
+        ► opkg update
+        """
+        super().sync()
+        self.run_cli("update")
