@@ -15,11 +15,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-import simplejson as json
-from boltons.cacheutils import cachedproperty
-from click_extra.logging import logger
+import json
+import sys
+
+if sys.version_info >= (3, 8):
+    from functools import cached_property
+else:
+    from boltons.cacheutils import cachedproperty as cached_property
+
 from click_extra.platform import LINUX, MACOS, WINDOWS
 
+from .. import logger
 from ..base import PackageManager
 from ..version import parse_version
 
@@ -79,6 +85,53 @@ class Yarn(PackageManager):
         output = self.run_cli("global", "--json", "list", "--depth", "0")
         return self.parse(output)
 
+    @cached_property
+    def global_dir(self):
+        """.. code-block:: shell-session.
+
+        ► yarn global dir (...)
+        """
+        return self.run_cli("global", "dir", force_exec=True).rstrip()
+
+    @property
+    def outdated(self):
+        """Fetch outdated packages from ``yarn outdated`` output.
+
+        Raw CLI output samples:
+
+        .. code-block:: shell-session
+
+            ► yarn --json outdated --cwd <self.global_dir>
+            (...)
+        """
+        outdated = {}
+
+        output = self.run_cli("--json", "outdated", "--cwd", self.global_dir)
+
+        packages = []
+        for line in output.splitlines():
+            if not line:
+                continue
+            obj = json.loads(line)
+            if obj["type"] == "table":
+                packages = obj["data"]["body"]
+                break
+
+        for package in packages:
+            package_id = package[0]
+            values = {"current": package[1], "wanted": package[2], "latest": package[3]}
+
+            if values["wanted"] == "linked":
+                continue
+            outdated[package_id] = {
+                "id": package_id + "@" + values["latest"],
+                "name": package_id,
+                "installed_version": parse_version(values["current"]),
+                "latest_version": parse_version(values["latest"]),
+            }
+
+        return outdated
+
     def search(self, query, extended, exact):
         """Call ``yarn info`` and only works for exact match.
 
@@ -185,76 +238,42 @@ class Yarn(PackageManager):
 
         return matches
 
-    @cachedproperty
-    def global_dir(self):
-        return self.run_cli("global", "dir", force_exec=True).rstrip()
-
     def install(self, package_id):
         """Install one package.
 
         .. code-block:: shell-session
 
             ► yarn install python
-
         """
         super().install(package_id)
         return self.run_cli("install", package_id)
 
-    @property
-    def outdated(self):
-        """Fetch outdated packages from ``yarn outdated`` output.
+    def upgrade_cli(self, package_id=None):
+        """.. code-block:: shell-session.
 
-        Raw CLI output samples:
+            ► yarn global add python
 
         .. code-block:: shell-session
 
-            ► yarn --json outdated --cwd
-            (...)
+            ► yarn global upgrade
         """
-        outdated = {}
-
-        output = self.run_cli("--json", "outdated", "--cwd", self.global_dir)
-
-        if not output:
-            return outdated
-
-        packages = []
-        for line in output.splitlines():
-            if not line:
-                continue
-            obj = json.loads(line)
-            if obj["type"] == "table":
-                packages = obj["data"]["body"]
-                break
-
-        for package in packages:
-            package_id = package[0]
-            values = {"current": package[1], "wanted": package[2], "latest": package[3]}
-
-            if values["wanted"] == "linked":
-                continue
-            outdated[package_id] = {
-                "id": package_id + "@" + values["latest"],
-                "name": package_id,
-                "installed_version": parse_version(values["current"]),
-                "latest_version": parse_version(values["latest"]),
-            }
-        return outdated
-
-    def upgrade_cli(self, package_id=None):
-        cmd = [self.cli_path, "global"]
-
+        cmd_args = []
         if package_id:
-            cmd.append("add")
-            cmd.append(package_id)
+            cmd_args += ["add", package_id]
         else:
-            cmd.append("upgrade")
-
-        return cmd
+            cmd_args += ["upgrade"]
+        return self.build_cli(
+            "global",
+            *cmd_args,
+        )
 
     def cleanup(self):
         """Remove the shared cache files.
 
+        .. code-block:: shell-session
+
+            ► yarn cache clean --all
+
         See: https://yarnpkg.com/cli/cache/clean
         """
         super().cleanup()
