@@ -15,6 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+import ast
 import re
 from operator import attrgetter
 from pathlib import Path, PurePath
@@ -22,9 +23,12 @@ from string import ascii_letters, ascii_lowercase, digits
 from types import MethodType
 
 import pytest
+from boltons.iterutils import unique
 from click_extra.platform import OS_DEFINITIONS
 
-from ..pool import ALL_MANAGER_IDS, pool
+from ..base import PackageManager
+from ..cli import XKCD_MANAGER_ORDER
+from ..pool import pool
 from ..version import TokenizedString
 
 """ Test the structure, data and types returned by all package managers.
@@ -34,10 +38,10 @@ new package manager definitions.
 """
 
 # Parametrization decorators.
-all_managers = pytest.mark.parametrize("manager", pool().values(), ids=attrgetter("id"))
+all_managers = pytest.mark.parametrize("manager", pool.values(), ids=attrgetter("id"))
 
 
-@pytest.mark.parametrize("manager_id,manager", pool().items())
+@pytest.mark.parametrize("manager_id,manager", pool.items())
 def test_ascii_id(manager_id, manager):
     """All package manager IDs should be short ASCII strings."""
     assert manager_id
@@ -56,7 +60,12 @@ def test_name(manager):
 
 
 def test_unique_names():
-    assert len({m.name for m in pool().values()}) == len(ALL_MANAGER_IDS)
+    assert len({m.name for m in pool.values()}) == len(pool.all_manager_ids)
+
+
+def test_xkcd_set():
+    assert len(unique(XKCD_MANAGER_ORDER)) == len(XKCD_MANAGER_ORDER)
+    assert set(pool.all_manager_ids).issuperset(XKCD_MANAGER_ORDER)
 
 
 @all_managers
@@ -109,16 +118,24 @@ def test_cli_path(manager):
 @all_managers
 def test_global_args_type(manager):
     """Check that definitions returns CLI args as a list of strings."""
-    assert isinstance(manager.global_args, tuple)
-    for arg in manager.global_args:
-        assert arg
-        assert isinstance(arg, str)
-        assert set(arg).issubset(ascii_letters + digits + "-=")
+    for global_args in (manager.pre_cmds, manager.pre_args, manager.post_args):
+        assert isinstance(global_args, tuple)
+        for arg in global_args:
+            assert arg
+            assert isinstance(arg, str)
+            assert set(arg).issubset(ascii_letters + digits + "-=")
 
 
 @all_managers
-def test_prepend_global_args(manager):
-    assert isinstance(manager.prepend_global_args, bool)
+def test_global_env_type(manager):
+    """Check that definitions environment variables as a dict of strings."""
+    assert manager.extra_env is None or isinstance(manager.extra_env, dict)
+    if manager.extra_env:
+        for key, value in manager.extra_env.items():
+            for item in (key, value):
+                assert item
+                assert isinstance(item, str)
+                assert set(item).issubset(ascii_letters + digits + "_-")
 
 
 @all_managers
@@ -141,7 +158,10 @@ def test_version_cli_options(manager):
 
 @all_managers
 def test_version_regex(manager):
-    """Version regex is required. Check it compiles and match has a version group."""
+    """Version regex is required.
+
+    Check it compiles and match has a version group.
+    """
     assert isinstance(manager.version_regex, str)
     regex = re.compile(manager.version_regex)
     assert "version" in regex.groupindex
@@ -175,20 +195,21 @@ def test_available(manager):
 
 @all_managers
 def test_cli_type(manager):
-    """Check that all methods returning a CLI is either not implemented or returns a list."""
+    """Check that all methods returning a CLI is either not implemented or returns a
+    tuple."""
     try:
         result = manager.upgrade_cli("dummy_package_id")
-    except Exception as excpt:
-        assert isinstance(excpt, NotImplementedError)
+    except Exception as ex:
+        assert isinstance(ex, NotImplementedError)
     else:
-        assert isinstance(result, list)
+        assert isinstance(result, tuple)
 
     try:
         result = manager.upgrade_all_cli()
-    except Exception as excpt:
-        assert isinstance(excpt, NotImplementedError)
+    except Exception as ex:
+        assert isinstance(ex, NotImplementedError)
     else:
-        assert isinstance(result, list)
+        assert isinstance(result, tuple)
 
 
 @all_managers
@@ -211,8 +232,8 @@ def test_search_type(manager):
     if manager.available:
         try:
             matches = manager.search("python", extended=True, exact=False)
-        except Exception as excpt:
-            assert isinstance(excpt, NotImplementedError)
+        except Exception as ex:
+            assert isinstance(ex, NotImplementedError)
         else:
             assert isinstance(matches, dict)
             for pkg in matches.values():
@@ -230,8 +251,8 @@ def test_outdated_type(manager):
     if manager.available:
         try:
             result = manager.outdated
-        except Exception as excpt:
-            assert isinstance(excpt, NotImplementedError)
+        except Exception as ex:
+            assert isinstance(ex, NotImplementedError)
         else:
             assert isinstance(result, dict)
             for pkg in manager.outdated.values():
@@ -258,3 +279,35 @@ def test_cleanup_type(manager):
     if manager.available:
         assert isinstance(manager.cleanup, MethodType)
         assert manager.cleanup() is None
+
+
+# Build the canonical reference from the base class.
+# The class' internal dict is sorted with the same order the code is
+# structured. No need for AST parsing.
+props_ref = tuple(
+    prop for prop in PackageManager.__dict__.keys() if not prop.startswith("_")
+)
+
+# Check the code of each file registered in the pool.
+@pytest.mark.parametrize("manager_file", pool.manager_files, ids=attrgetter("name"))
+def test_content_order(manager_file):
+    """Lint each package manager definition file to check its code structure is the same
+    as the canonical PackageManager base class."""
+
+    tree = ast.parse(manager_file.read_bytes())
+
+    # Analyse each class.
+    for klass in (n for n in tree.body if isinstance(n, ast.ClassDef)):
+
+        # Collect in order the IDs of all properties (ast.Assign) and functions in
+        # the class.
+        collected_props = []
+        for node in klass.body:
+            if isinstance(node, ast.Assign):
+                collected_props.extend([t.id for t in node.targets])
+            if isinstance(node, ast.FunctionDef):
+                collected_props.append(node.name)
+
+        enforced_props = tuple(p for p in collected_props if p in props_ref)
+        expected_order = tuple(p for p in props_ref if p in collected_props)
+        assert enforced_props == expected_order
