@@ -18,52 +18,45 @@
 import pytest
 
 from ..cli import mpm
-from ..pool import (
-    ALL_MANAGER_IDS,
-    ALLOWED_EXTRA_OPTION,
-    DEFAULT_MANAGER_IDS,
-    UNSUPPORTED_MANAGER_IDS,
-    pool,
-    select_managers,
-)
+from ..pool import pool
 
 """ Test the pool and its content. """
 
 
 def test_manager_count():
     """Check all implemented package managers are accounted for, and unique."""
-    assert len(pool()) == 16
-    assert len(pool()) == len(ALL_MANAGER_IDS)
-    assert ALL_MANAGER_IDS == tuple(sorted(set(pool())))
+    assert len(pool) == 18
+    assert len(pool) == len(pool.all_manager_ids)
+    assert pool.all_manager_ids == tuple(sorted(set(pool)))
 
 
 def test_cached_pool():
-    assert pool() == pool()
-    assert pool() is pool()
+    assert pool == pool
+    assert pool is pool
 
 
-@pytest.mark.parametrize("manager_id", DEFAULT_MANAGER_IDS)
+@pytest.mark.parametrize("manager_id", pool.default_manager_ids)
 def test_supported_managers(manager_id):
-    assert pool()[manager_id].supported is True
+    assert pool[manager_id].supported is True
 
 
-@pytest.mark.parametrize("manager_id", UNSUPPORTED_MANAGER_IDS)
+@pytest.mark.parametrize("manager_id", pool.unsupported_manager_ids)
 def test_unsupported_managers(manager_id):
-    assert pool()[manager_id].supported is False
+    assert pool[manager_id].supported is False
 
 
 def test_manager_groups():
-    assert len(DEFAULT_MANAGER_IDS) + len(UNSUPPORTED_MANAGER_IDS) == len(
-        ALL_MANAGER_IDS
+    assert len(pool.default_manager_ids) + len(pool.unsupported_manager_ids) == len(
+        pool.all_manager_ids
     )
     assert (
-        tuple(sorted(set(DEFAULT_MANAGER_IDS).union(UNSUPPORTED_MANAGER_IDS)))
-        == ALL_MANAGER_IDS
+        tuple(sorted(set(pool.default_manager_ids).union(pool.unsupported_manager_ids)))
+        == pool.all_manager_ids
     )
 
 
 def test_extra_option_allowlist():
-    assert ALLOWED_EXTRA_OPTION.issubset(opt.name for opt in mpm.params)
+    assert pool.ALLOWED_EXTRA_OPTION.issubset(opt.name for opt in mpm.params)
 
 
 selection_cases = {
@@ -93,15 +86,15 @@ selection_cases = {
     ),
     "single_exclusion": (
         {"drop": ("apm")},
-        tuple(mid for mid in DEFAULT_MANAGER_IDS if mid != "apm"),
+        tuple(mid for mid in pool.default_manager_ids if mid != "apm"),
     ),
     "duplicate_exclusions": (
         {"drop": ("apm", "apm")},
-        tuple(mid for mid in DEFAULT_MANAGER_IDS if mid != "apm"),
+        tuple(mid for mid in pool.default_manager_ids if mid != "apm"),
     ),
     "multiple_exclusions": (
         {"drop": ("apm", "gem")},
-        tuple(mid for mid in DEFAULT_MANAGER_IDS if mid not in ("apm", "gem")),
+        tuple(mid for mid in pool.default_manager_ids if mid not in ("apm", "gem")),
     ),
     "selector_priority": (
         {"keep": ("apm"), "drop": ("gem")},
@@ -113,23 +106,23 @@ selection_cases = {
     ),
     "default_selection": (
         {},
-        DEFAULT_MANAGER_IDS,
+        pool.default_manager_ids,
     ),
     "drop_unsupported": (
         {"drop_unsupported": True},
-        DEFAULT_MANAGER_IDS,
+        pool.default_manager_ids,
     ),
     "keep_unsupported": (
         {"drop_unsupported": False},
-        ALL_MANAGER_IDS,
+        pool.all_manager_ids,
     ),
     "drop_inactive": (
         {"drop_inactive": True},
-        tuple(mid for mid in DEFAULT_MANAGER_IDS if pool()[mid].available),
+        tuple(mid for mid in pool.default_manager_ids if pool[mid].available),
     ),
     "keep_inactive": (
         {"drop_inactive": False},
-        DEFAULT_MANAGER_IDS,
+        pool.default_manager_ids,
     ),
 }
 
@@ -144,5 +137,5 @@ selection_cases = {
 def select_managers(kwargs, expected):
     """We use tuple everywhere so we can check that select_managers() conserve the
     original order."""
-    selection = select_managers(**kwargs)
+    selection = pool.select_managers(**kwargs)
     assert tuple(selection) == expected
